pub enum TurnEvent {
AllocationCreated(TransportType, SocketAddr),
AllocationCreateFailed,
PermissionCreated(TransportType, IpAddr),
PermissionCreateFailed(TransportType, IpAddr),
}Expand description
A set of events that can occur within a TURN client’s connection to a TURN server.
Variants
AllocationCreated(TransportType, SocketAddr)
An allocation was created on the server for the client. The allocation as the associated transport and address.
AllocationCreateFailed
Allocation failed to be created.
PermissionCreated(TransportType, IpAddr)
A permission was created for the provided transport and IP address.
PermissionCreateFailed(TransportType, IpAddr)
A permission could not be installed for the provided transport and IP address.