pub enum TurnPollRet {
WaitUntil(Instant),
Closed,
}Expand description
Return value from calling poll().
Variants
WaitUntil(Instant)
The caller should wait until the provided time. Other events may cause this value to modified and poll() should be rechecked.
Closed
The connection is closed and no further progress will be made.